==> sdx-2.2.2-src.tar.gz: sdx-2.2.2/src/java/fr/gouv/culture/sdx/utils/xml/SimpleXPathString.java <==
/*
SDX: Documentary System in XML.
Copyright (C) 2000, 2001, 2002  Ministere de la culture et de la communication (France), AJLSM

Ministere de la culture et de la communication,
Mission de la recherche et de la technologie
3 rue de Valois, 75042 Paris Cedex 01 (France)
mrt@culture.fr, michel.bottin@culture.fr

AJLSM, 17, rue Vital Carles, 33000 Bordeaux (France)
sevigny@ajlsm.com

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
or connect to:
http://www.fsf.org/copyleft/gpl.html
*/
package fr.gouv.culture.sdx.utils.xml;

/**
 * Created by IntelliJ IDEA.
 * User: rpandey
 * Date: Aug 22, 2003
 * Time: 10:48:38 AM
 * To change this template use Options | File Templates.
 */
public class SimpleXPathString {
    protected String localXPath = "";
    protected String qualifiedXPath = "";

    public String concatLocalXPath(String localName) {
        localXPath += "/" + localName;
        return localXPath;
    }

    public String concatQualifiedXPath(String qualifiedName) {
        qualifiedXPath += "/" + qualifiedName;
        return qualifiedXPath;
    }

    public String trimLocalXPath(String localName) {
        localXPath = localXPath.substring(0, localXPath.lastIndexOf("/" + localName));
        return localXPath;
    }

    public String trimQualifiedXPath(String localName) {
        qualifiedXPath = qualifiedXPath.substring(0, qualifiedXPath.lastIndexOf("/" + localName));
        return qualifiedXPath;
    }

    public String getLocalXPath() {
        return localXPath;
    }

    public String getQualifiedXPath() {
        return qualifiedXPath;
    }
    /*
    *What about root matches like //* ?
    *What about matches like /* ?
    */


}

==> sdx-2.3b1-src.tar.gz: sdx-2.3b1/src/java/fr/gouv/culture/sdx/utils/xml/SimpleXPathString.java <==
/*
SDX: Documentary System in XML.
Copyright (C) 2000, 2001, 2002  Ministere de la culture et de la communication (France), AJLSM

Ministere de la culture et de la communication,
Mission de la recherche et de la technologie
3 rue de Valois, 75042 Paris Cedex 01 (France)
mrt@culture.fr, michel.bottin@culture.fr

AJLSM, 17, rue Vital Carles, 33000 Bordeaux (France)
sevigny@ajlsm.com

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
or connect to:
http://www.fsf.org/copyleft/gpl.html
*/
package fr.gouv.culture.sdx.utils.xml;

import java.util.Stack;

/**
 * Created by IntelliJ IDEA.
 * User: rpandey
 * Date: Aug 22, 2003
 * Time: 10:48:38 AM
 * To change this template use Options | File Templates.
 */
public class SimpleXPathString {
    protected Stack uris = new Stack();
    protected String localXPath = "";
    protected String qualifiedXPath = "";

    public String getUri() {
        return (String) uris.peek();
    }

    public void removeUri(String uri) {
        uris.remove(uri);
    }

    public void setUri(String uri) {
        uris.push(uri);
    }

    public String concatLocalXPath(String localName) {
        localXPath += "/" + localName;
        return localXPath;
    }

    public String concatQualifiedXPath(String qualifiedName) {
        qualifiedXPath += "/" + qualifiedName;
        return qualifiedXPath;
    }

    public String trimLocalXPath(String localName) {
        localXPath = localXPath.substring(0, localXPath.lastIndexOf("/" + localName));
        return localXPath;
    }

    public String trimQualifiedXPath(String localName) {
        qualifiedXPath = qualifiedXPath.substring(0, qualifiedXPath.lastIndexOf("/" + localName));
        return qualifiedXPath;
    }

    public String getLocalXPath() {
        return localXPath;
    }

    public String getQualifiedXPath() {
        return qualifiedXPath;
    }
    /*
    *What about root matches like //* ?
    *What about matches like /* ?
    */


}
